@@ -1,7 +1,7 @@
 """pantsonfire - Find wrong information in technical docs online"""
 
-__version__ = "0.1.0"
+__version__ = "0.3.7"
 
 from .factory import create_app
 
-__all__ = ["create_app"]
+__all__ = ["create_app", "__version__"]
