@@ -14,6 +14,7 @@ from .models import CheckResult
 @click.group()
 @click.option('--mode', default='external', help='Operation mode: internal or external')
 @click.option('--config', type=click.Path(exists=True), help='Path to config file')
+@click.version_option(package_name='pantsonfire')
 @click.pass_context
 def cli(ctx, mode, config):
     """Pantsonfire - Find wrong information in technical docs online"""
@@ -183,8 +184,9 @@ def config(ctx, model, api_key, test):
         try:
             app = create_app(mode=ctx.obj['mode'])
             # Simple test prompt
+            from .models_config import DEFAULT_MODEL
             test_result = app.llm.client.chat.completions.create(
-                model="anthropic/claude-3-haiku",
+                model=DEFAULT_MODEL,
                 messages=[{"role": "user", "content": "Hello, test message"}],
                 max_tokens=10
             )
@@ -504,6 +506,223 @@ def extract_keywords_from_issue(issue: str) -> List[str]:
     return keywords
 
 
+@cli.command()
+@click.argument('target_url')
+@click.option('--truth-sources', '-t', multiple=True, help='Truth source URLs (docs, GitHub, etc.)')
+@click.option('--max-pages', '-n', type=int, default=10, help='Maximum pages to analyze')
+@click.option('--depth', '-d', type=int, default=1, help='Crawl depth')
+@click.option('--granularity', type=click.Choice(['sentence', 'paragraph', 'section']), default='paragraph', help='Factoid extraction granularity')
+@click.option('--hints', help='Natural language hints about what to look for')
+@click.option('--build-registry', is_flag=True, help='Build and save truth registry to Oxen')
+@click.option('--model', help='Model to use for factoid extraction (default: free Grok, or set in config)')
+@click.option('--remediate', type=click.Choice(['suggestions', 'oxen-notes', 'github-issues']), help='Remediation mode')
+@click.option('--quiet', '-q', is_flag=True, help='Quiet mode')
+@click.option('--verbose', '-v', is_flag=True, help='Verbose mode - show LLM request/response details')
+@click.option('--dry-run', is_flag=True, help='Show what would be done without creating issues/PRs')
+@click.pass_context
+def crawl(ctx, target_url, truth_sources, max_pages, depth, granularity, hints, build_registry, model, remediate, quiet, verbose, dry_run):
+    """
+    Crawl a website, extract factoids, and build a truth registry.
+    
+    Example:
+      pantsonfire crawl https://oxen.ai/blog \\
+        --truth-sources "https://docs.oxen.ai" \\
+        --truth-sources "https://github.com/Oxen-AI/Oxen" \\
+        --max-pages 10 \\
+        --hints "mintlify docs are authoritative" \\
+        --build-registry \\
+        --remediate suggestions \\
+        --dry-run
+    """
+    try:
+        from .factoid import FactoidExtractor, ContentTypeClassifier, TimestampDetector, FactoidDeduplicator
+        from .truth_registry import TruthRegistry
+        from .model_manager import ModelManager, BatchProcessor
+        from .remediation import RemediationOrchestrator
+        from .extractors.external import ExternalExtractor
+        from .extractors.web_scraper import WebScraper
+        
+        if not quiet:
+            import pantsonfire
+            click.echo(f"\n🔥 Pantsonfire v{pantsonfire.__version__} - Self-Driving Fact Checker")
+            click.echo(f"{'='*80}")
+            click.echo(f"Target: {target_url}")
+            click.echo(f"Truth Sources: {len(truth_sources)}")
+            click.echo(f"Max Pages: {max_pages}")
+            click.echo(f"{'='*80}\n")
+        
+        # Setup
+        config_overrides = {}
+        if model:
+            config_overrides["model"] = model
+        
+        app = create_app(mode="external", config=config_overrides)
+        
+        # Initialize components
+        llm_client = app.llm
+        extractor_engine = FactoidExtractor(llm_client, app.config, verbose=verbose)
+        classifier = ContentTypeClassifier()
+        timestamp_detector = TimestampDetector()
+        deduplicator = FactoidDeduplicator()
+        model_manager = ModelManager(app.config)
+        content_extractor = ExternalExtractor()
+        
+        # Step 1: Discover pages to analyze
+        if not quiet:
+            click.echo("🕷️  Step 1: Discovering pages to analyze...")
+        
+        scraper = WebScraper(app.config)
+        discovered_urls = scraper.discover_pages(target_url, max_pages=max_pages, depth=depth)
+        
+        if not discovered_urls:
+            discovered_urls = [target_url]  # Fallback to just the target
+        
+        if not quiet:
+            click.echo(f"✅ Found {len(discovered_urls)} pages to analyze")
+        
+        # Step 2: Extract factoids from all pages
+        if not quiet:
+            click.echo(f"\n🧠 Step 2: Extracting factoids...")
+        
+        all_factoids = []
+        
+        for i, url in enumerate(discovered_urls, 1):
+            if not quiet:
+                click.echo(f"  [{i}/{len(discovered_urls)}] {url}")
+            
+            content = content_extractor.extract(url)
+            if not content:
+                continue
+            
+            content_type = classifier.classify(url, content)
+            timestamp = timestamp_detector.detect_timestamp(content)
+            
+            factoids = extractor_engine.extract_factoids(
+                content,
+                url,
+                content_type,
+                granularity
+            )
+            
+            # Set timestamps
+            for factoid in factoids:
+                factoid.published_at = timestamp
+            
+            all_factoids.extend(factoids)
+            
+            if not quiet:
+                click.echo(f"    → {len(factoids)} factoids ({content_type})")
+        
+        if not quiet:
+            click.echo(f"\n✅ Total factoids extracted: {len(all_factoids)}")
+        
+        # Step 3: Deduplicate
+        if not quiet:
+            click.echo(f"\n🔄 Step 3: Deduplicating factoids...")
+        
+        unique_factoids = deduplicator.deduplicate(all_factoids)
+        
+        if not quiet:
+            click.echo(f"  {len(all_factoids)} → {len(unique_factoids)} unique factoids")
+        
+        # Step 4: Build truth registry
+        if not quiet:
+            click.echo(f"\n📊 Step 4: Building truth registry...")
+        
+        registry = TruthRegistry(app.config, "truth-registry")
+        registry.add_factoids(unique_factoids)
+        
+        # Step 4.5: Verify factoids against truth sources if provided
+        if truth_sources and llm_client and llm_client.client:
+            if not quiet:
+                click.echo(f"\n🔍 Step 4.5: Verifying factoids against truth sources...")
+            
+            # For now, use basic verification (web search verification would be expensive)
+            # Just mark factoids from authoritative sources as more trustworthy
+            for factoid in unique_factoids:
+                # If factoid came from a truth source, mark it as likely true
+                if any(truth_src in factoid.source_url for truth_src in truth_sources):
+                    factoid.truth_score = 0.9  # High confidence for factoids from truth sources
+                else:
+                    # Factoids from non-truth sources get default/lower score
+                    factoid.truth_score = 0.4  # Lower confidence for blog/non-authoritative sources
+            
+            if not quiet:
+                high_truth = len([f for f in unique_factoids if f.truth_score >= 0.7])
+                low_truth = len([f for f in unique_factoids if f.truth_score < 0.5])
+                click.echo(f"  ✅ High confidence: {high_truth}, Low confidence: {low_truth}")
+        
+        # Step 5: Calculate accuracy
+        if not quiet:
+            click.echo(f"\n🎯 Step 5: Calculating accuracy scores...")
+        
+        # Get domain from target URL
+        from urllib.parse import urlparse
+        domain = urlparse(target_url).netloc
+        
+        domain_accuracy = registry.get_accuracy_by_domain(domain)
+        
+        click.echo(f"\n📈 ACCURACY REPORT")
+        click.echo(f"{'='*80}")
+        click.echo(f"Domain: {domain}")
+        click.echo(f"Overall Accuracy: {domain_accuracy['accuracy_score']:.1f}%")
+        click.echo(f"Total Factoids: {domain_accuracy['total_factoids']}")
+        click.echo(f"URLs Analyzed: {domain_accuracy['total_urls']}")
+        
+        # Show per-URL breakdown
+        if not quiet and domain_accuracy.get('url_breakdown'):
+            click.echo(f"\nPer-URL Breakdown:")
+            for url_data in domain_accuracy['url_breakdown'][:5]:
+                emoji = "✅" if url_data['accuracy_score'] >= 70 else "⚠️" if url_data['accuracy_score'] >= 50 else "❌"
+                click.echo(f"  {emoji} {url_data['url']}")
+                click.echo(f"     Accuracy: {url_data['accuracy_score']:.1f}% ({url_data['total_factoids']} factoids)")
+        
+        click.echo(f"{'='*80}\n")
+        
+        # Step 6: Save to Oxen if requested
+        if build_registry:
+            if not quiet:
+                click.echo(f"💾 Step 6: Saving truth registry to Oxen...")
+            
+            success = registry.save_to_oxen(app.storage)
+            if success:
+                click.echo(f"✅ Truth registry saved to Oxen")
+            else:
+                click.echo(f"⚠️  Failed to save to Oxen - data kept locally")
+        
+        # Step 7: Remediation
+        if remediate:
+            if not quiet:
+                click.echo(f"\n🔧 Step 7: Running remediation ({remediate} mode)...")
+            
+            remediation_engine = RemediationOrchestrator(app.config, llm_client, mode=remediate)
+            
+            # Build truth evidence map
+            truth_map = {}
+            for factoid in unique_factoids:
+                if factoid.truth_sources:
+                    truth_map[factoid.factoid_id] = f"See: {', '.join(factoid.truth_sources[:2])}"
+            
+            results = remediation_engine.remediate_factoids(unique_factoids, truth_map, dry_run=dry_run)
+            
+            # Generate report
+            report = remediation_engine.generate_summary_report(results)
+            click.echo(report)
+        
+        # Final summary
+        click.echo(f"\n🎉 CRAWL COMPLETE")
+        click.echo(f"  Factoids: {len(unique_factoids)}")
+        click.echo(f"  Accuracy: {domain_accuracy['accuracy_score']:.1f}%")
+        click.echo(f"  Registry: {'Saved to Oxen' if build_registry else 'Not saved'}")
+        
+    except Exception as e:
+        click.echo(f"Error: {e}", err=True)
+        if not quiet:
+            import traceback
+            traceback.print_exc()
+        sys.exit(1)
+
+
 def main():
     """Entry point for the CLI"""
     cli()
