@@ -32,7 +32,7 @@ def create_app(mode: str = "internal", config: Optional[Dict[str, Any]] = None)
         "openrouter_api_key": os.getenv("OPENROUTER_API_KEY"),
         "oxen_api_key": os.getenv("OXEN_API_KEY"),
         "openrouter_base_url": "https://openrouter.ai/api/v1",
-        "model": "anthropic/claude-3-haiku",  # Default to cheaper model, can be overridden
+        # Model is set from models_config.DEFAULT_MODEL via Config class
         "storage_path": Path("./pantsonfire_logs.json"),
         "confidence_threshold": 0.7,
         "max_chunk_size": 2000,
