@@ -356,7 +356,7 @@ class OxenStorage(StorageBackend):
 
     def _populate_repository_with_data(self, results: List[CheckResult], temp_path: Path) -> bool:
         """
-        Populate the repository with analysis data using Oxen's workspace system.
+        Populate the repository with analysis data using Oxen Python SDK.
 
         Args:
             results: Analysis results to store
@@ -366,76 +366,82 @@ class OxenStorage(StorageBackend):
             True if data was successfully added to the repository
         """
         try:
-            # Step 1: Create a workspace for this repository
-            workspace_name = f"analysis_{datetime.now().strftime('%Y%m%d_%H%M%S')}"
-
-            # Create workspace
-            workspace_data = {"name": workspace_name}
-            response = self.session.post(
-                f"{self.base_url}/api/repos/{self.namespace}/{self.current_repo}/workspaces",
-                json=workspace_data
-            )
-
-            if response.status_code not in [200, 201]:
-                print(f"⚠️  Could not create workspace: {response.status_code} - {response.text}")
-                return False
-
-            workspace_info = response.json()
-            print(f"✅ Created workspace: {workspace_name}")
-
-            # Step 2: Add data to the workspace
-            # Convert results to JSON for upload
-            results_data = [result.model_dump() for result in results]
-
-            # Create a dataframe with the results
-            dataframe_data = {
-                "name": "findings",
-                "data": results_data,
-                "schema": {
-                    "fields": [
-                        {"name": "blog_source", "dtype": "str"},
-                        {"name": "truth_source", "dtype": "str"},
-                        {"name": "discrepancy", "dtype": "str"},
-                        {"name": "confidence", "dtype": "float"},
-                        {"name": "evidence", "dtype": "str"},
-                        {"name": "chunk_index", "dtype": "int"},
-                        {"name": "timestamp", "dtype": "datetime"}
-                    ]
-                }
-            }
-
-            # Add dataframe to workspace
-            response = self.session.post(
-                f"{self.base_url}/api/repos/{self.namespace}/{self.current_repo}/workspaces/{workspace_name}/dataframes",
-                json=dataframe_data
-            )
-
-            if response.status_code not in [200, 201]:
-                print(f"⚠️  Could not add dataframe: {response.status_code} - {response.text}")
-                return False
-
-            print(f"✅ Added findings dataframe to workspace")
-
-            # Step 3: Commit the workspace to create a permanent record
-            commit_data = {
-                "message": f"Pantsonfire analysis: {len(results)} findings detected",
-                "author": "pantsonfire"
-            }
-
-            response = self.session.post(
-                f"{self.base_url}/api/repos/{self.namespace}/{self.current_repo}/workspaces/{workspace_name}/commit",
-                json=commit_data
-            )
-
-            if response.status_code in [200, 201]:
-                print(f"✅ Committed analysis data to repository")
-                return True
-            else:
-                print(f"⚠️  Could not commit workspace: {response.status_code} - {response.text}")
-                return False
-
+            import oxen
+            import pandas as pd
+            
+            # Create a temporary local Oxen repository
+            local_repo_path = temp_path / "oxen_repo"
+            local_repo_path.mkdir(exist_ok=True)
+            
+            # Initialize the local repository
+            oxen.init(str(local_repo_path))
+            
+            # Create pandas DataFrame from results
+            df_data = []
+            for result in results:
+                df_data.append({
+                    "blog_source": result.blog_source,
+                    "truth_source": result.truth_source,
+                    "discrepancy": result.discrepancy,
+                    "confidence": result.confidence,
+                    "evidence": result.evidence,
+                    "chunk_index": result.chunk_index,
+                    "timestamp": result.timestamp.isoformat()
+                })
+            
+            df = pd.DataFrame(df_data)
+            
+            # Save DataFrame to the local repository
+            findings_file = local_repo_path / "findings.csv"
+            df.to_csv(findings_file, index=False)
+            
+            # Also save as JSON for easier viewing
+            json_file = local_repo_path / "findings.json"
+            import json
+            with open(json_file, 'w') as f:
+                json.dump(df_data, f, indent=2)
+            
+            # Create a README
+            readme_file = local_repo_path / "README.md"
+            with open(readme_file, 'w') as f:
+                f.write(f"# Pantsonfire Analysis Results\n\n")
+                f.write(f"**Total Findings**: {len(results)}\n\n")
+                f.write(f"**Analysis Date**: {datetime.now().isoformat()}\n\n")
+                f.write(f"## Summary\n\n")
+                for i, result in enumerate(results, 1):
+                    f.write(f"### Issue #{i}\n")
+                    f.write(f"- **Problem**: {result.discrepancy}\n")
+                    f.write(f"- **Confidence**: {result.confidence:.2f}\n")
+                    f.write(f"- **Evidence**: {result.evidence}\n\n")
+            
+            # Add files to Oxen
+            oxen.add(str(findings_file))
+            oxen.add(str(json_file))
+            oxen.add(str(readme_file))
+            
+            # Commit the files
+            oxen.commit(f"Pantsonfire analysis: {len(results)} findings detected")
+            
+            print(f"✅ Committed {len(results)} findings to local Oxen repository")
+            
+            # Set the remote and push
+            remote_url = f"https://hub.oxen.ai/{self.namespace}/{self.current_repo}"
+            oxen.config.set_remote("origin", remote_url)
+            
+            # Set authentication
+            if self.api_key:
+                oxen.auth.config_auth(host=self.base_url, token=self.api_key)
+            
+            # Push to remote
+            oxen.push("origin", "main")
+            
+            print(f"✅ Pushed analysis data to Oxen repository")
+            return True
+            
         except Exception as e:
             print(f"⚠️  Error populating repository with data: {e}")
+            import traceback
+            traceback.print_exc()
             return False
 
     def get_results(self, limit: Optional[int] = None) -> List[CheckResult]:
